==> ragel-1.3.3.tar.gz: ragel-1.3.3/aapl/avliset.h <==
/*
 *  Copyright 2002 Adrian Thurston <adriant@ragel.ca>
 */

/*  This file is part of Aapl.
 *
 *  Aapl is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 * 
 *  Aapl is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with Aapl; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */

#ifndef _AAPL_AVLISET_H
#define _AAPL_AVLISET_H

#include "compare.h"
#include "dlist.h"

/**
 * \addtogroup avltree 
 * @{
 */

/**
 * \class AvliSet
 * \brief Linked Key-only oriented tree.
 *
 * AvliSet stores only keys in nodes managed by the tree. AvliSet does not
 * require a Node class to be defined. It does require that a Key type and a
 * class containing a static Compare routine for Key be given. Items are
 * inserted with just a key value.
 *
 * AvliSet implicitly connects nodes with linked list pointers, allowing the
 * nodes to be walked in order using next and previous pointers.
 *
 * AvliSet assumes all elements in the tree are allocated on the heap and are
 * to be managed by the tree. This means that the class destructor will
 * delete the contents of the tree. A deep copy will cause existing elements
 * to be deleted first.
 *
 * \include ex_avliset.cpp
 */

/*@}*/

#define AVLTREE_SET
#define BASENODE(name) name
#define BASEKEY(name) name
#define BASECOMPARE(name) Compare::name
#define BASELIST DList< AvliSetNode<Key> >
#define AVLMEL_TEMPDEF class Key, class Compare
#define AVLMEL_TEMPUSE Key, Compare
#define AvlTree AvliSet
#define Node AvliSetNode<Key>
#define WALKABLE

#include "avlcommon.h"

#undef AVLTREE_SET
#undef BASENODE
#undef BASEKEY
#undef BASECOMPARE
#undef BASELIST
#undef AVLMEL_TEMPDEF
#undef AVLMEL_TEMPUSE
#undef AvlTree
#undef Node
#undef WALKABLE

#endif /* _AAPL_AVLISET_H */

==> ragel-1.4.1.tar.gz: ragel-1.4.1/aapl/avliset.h <==
/*
 *  Copyright 2002 Adrian Thurston <adriant@ragel.ca>
 */

/*  This file is part of Aapl.
 *
 *  Aapl is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 * 
 *  Aapl is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with Aapl; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */

#ifndef _AAPL_AVLISET_H
#define _AAPL_AVLISET_H

#include "compare.h"
#include "dlist.h"

/**
 * \addtogroup avltree 
 * @{
 */

/**
 * \class AvliSet
 * \brief Linked Key-only oriented tree.
 *
 * AvliSet stores only keys in nodes managed by the tree. AvliSet requires
 * that a Key type and a class containing a static Compare routine for Key
 * be given. Items are inserted with just a key value.
 *
 * AvliSet implicitly connects nodes with linked list pointers, allowing the
 * nodes to be walked in order using next and previous pointers.
 *
 * AvliSet assumes all elements in the tree are allocated on the heap and are
 * to be managed by the tree. This means that the class destructor will
 * delete the contents of the tree. A deep copy will cause existing elements
 * to be deleted first.
 *
 * \include ex_avliset.cpp
 */

/*@}*/

#define AVLTREE_SET
#define BASENODE(name) name
#define BASEKEY(name) name
#define BASECOMPARE(name) Compare::name
#define BASELIST DList< AvliSetNode<Key> >
#define AVLMEL_TEMPDEF class Key, class Compare
#define AVLMEL_TEMPUSE Key, Compare
#define AvlTree AvliSet
#define Node AvliSetNode<Key>
#define WALKABLE

#include "avlcommon.h"

#undef AVLTREE_SET
#undef BASENODE
#undef BASEKEY
#undef BASECOMPARE
#undef BASELIST
#undef AVLMEL_TEMPDEF
#undef AVLMEL_TEMPUSE
#undef AvlTree
#undef Node
#undef WALKABLE

#endif /* _AAPL_AVLISET_H */
